@@ -23,8 +23,9 @@
 from __future__ import with_statement
 
 # This is also evaluated by the build scripts
-VERSION='0.9.0.1'
+VERSION='0.9.0.4'
 import logging
+import logging.handlers
 logging.basicConfig(level=logging.WARNING,
                     format='%(relativeCreated)6d %(levelname)10s %(name)-20s %(message)s // %(filename)s:%(lineno)s',
                     )
@@ -46,6 +47,7 @@ import provider
 from threading import Thread
 import cachedownloader
 from actors.tts import TTS
+from re import sub
 #from actors.notify import Notify
 
 import connection
@@ -60,9 +62,11 @@ if len(argv) == 1:
 
 if '-v' in argv or '--remote' in argv:
     import colorer
-    import logging.handlers
     logging.getLogger('').setLevel(logging.DEBUG)
     logging.debug("Set log level to DEBUG")
+    
+if '--debug-http' in argv:
+    downloader.enable_http_debugging()
 
 if '--simple' in argv:
     import simplegui
@@ -142,7 +146,7 @@ class Core(gobject.GObject):
         'options_show_error': True,
         'options_show_html_description': False,
         'map_providers': [
-            ('OpenStreetMaps', {'remote_url': "http://a.tile.openstreetmap.org/%(zoom)d/%(x)d/%(y)d.png", 'prefix': 'OpenStreetMap I', 'max_zoom': 18}),
+            ('OpenStreetMaps', {'remote_url': "http://tile.openstreetmap.org/%(zoom)d/%(x)d/%(y)d.png", 'prefix': 'OpenStreetMap I', 'max_zoom': 18}),
             ('OpenCycleMaps', {'remote_url': 'http://a.tile.opencyclemap.org/cycle/%(zoom)d/%(x)d/%(y)d.png', 'prefix': 'OpenCycleMap', 'max_zoom': 18}),
         ],
         'options_map_double_size': False,
@@ -168,6 +172,14 @@ class Core(gobject.GObject):
         self._install_updates()
 
         self.__read_config()
+        
+        # Check tile URLs for outdated URLs after Openstreetmap URL change
+        for name, details in self.settings['map_providers']:
+            prev = details['remote_url']
+            details['remote_url'] = sub(r'//(.*).openstreetmap.org/', '//tile.openstreetmap.org/', prev)
+            if prev != details['remote_url']:
+                logger.info("Replaced url '%s' with '%s' because Openstreetmaps changed their URLs." % (prev, details['remote_url']))
+        
         self.connect('settings-changed', self.__on_settings_changed)
         self.connect('save-settings', self.__on_save_settings)
         self.create_recursive(self.settings['download_output_dir'])
@@ -183,8 +195,9 @@ class Core(gobject.GObject):
         #actor_tts = TTS(self)
         #actor_tts.connect('error', lambda caller, msg: self.emit('error', msg))
         #actor_notify = Notify(self)
-        self.emit('settings-changed', self.settings, self)
-        self.emit('fieldnotes-changed')  
+        
+        
+        
  
         if ('debug_log_to_http' in self.settings and self.settings['debug_log_to_http']) or '--remote' in argv:
             http_handler = logging.handlers.HTTPHandler("danielfett.de", "http://www.danielfett.de/files/collect.php")
@@ -192,11 +205,20 @@ class Core(gobject.GObject):
             logging.getLogger('').addHandler(buffering_handler)
             logging.getLogger('').setLevel(logging.DEBUG)
             logging.debug("Remote logging activated!")
+            # Now reset the setting to default
+            self.settings['debug_log_to_http'] = False
+        
+        
+        self.emit('settings-changed', self.settings, self)
+        self.emit('fieldnotes-changed')  
 
         if '--sim' in argv:
             self.gps_thread = gpsreader.FakeGpsReader(self)
             gobject.timeout_add(1000, self.__read_gps)
             self.set_target(gpsreader.FakeGpsReader.get_target())
+        elif '--nogps' in argv:
+            self.gps_thread = gpsreader.FakeGpsReader(self)
+            self.set_target(gpsreader.FakeGpsReader.get_target())
         elif 'gpsprovider' in self.gui.USES:
             self.gps_thread = gpsreader.GpsReader()
             #self.gps_thread = gpsreader.FakeGpsReader(self)
